## Backtest
End-to-end, company wise performance
## Golden Path
~ an episode
## XXX - tests
to track code health


same as before, index error is not something backtests should concern themselves with, a golden_path returns the achieved reward, anything else is an exception but this is not a test and captures primarily our overall performance metric, as end to end as possible


Pasta is A code-first agent framework for seamlessly building and deploying AI Agents.

Pasta framework allows developers to define an agent as code, providing a variety of agent-native plugins out of the box.

BringYourOwnBrain: Pasta does not interfers with the brain if your agent, meaning we don’t dictate how your agent's inner logic should be created, 
write it yourself, use a provided plugin or third party library, once it's a node, it's all the same.

Unlike many agent frameworks pasta is an end to end solution, meaning an agent built on pasta can scale from prototype to production without undergoing large code changes.
